twoplot_sepa: twoplot_sepa

Description Usage Examples

View source: R/twoplot_sepa.R

Description

This function makes two plots and shows separated two plots at the same time and summarizes each data.

Usage

1
twoplot_sepa(data1, x1, plot1, data2, x2, plot2)

Examples

1
twoplot_sepa(iris,iris$Sepal.Length, "point", iris,iris$Petal.Length, "box")

sparklingyouth/easy.visualize documentation built on June 8, 2020, 12:40 a.m.