This function makes two plots and shows separated two plots at the same time and summarizes each data.
1 | twoplot_sepa(data1, x1, plot1, data2, x2, plot2)
|
1 | twoplot_sepa(iris,iris$Sepal.Length, "point", iris,iris$Petal.Length, "box")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.